import { SpreadsheetVisualDataBase } from "./SpreadsheetVisualDataBase";
import { IEnumerable, Type } from "igniteui-webcomponents-core";
import { RectData } from "igniteui-webcomponents-core";
import { PrimitiveVisualDataList } from "igniteui-webcomponents-core";
import { List$1 } from "igniteui-webcomponents-core";
import { ColorData } from "igniteui-webcomponents-core";
/**
 * Represents the visual data for the spreadsheet.
 */
export declare class SpreadsheetVisualData extends SpreadsheetVisualDataBase {
    static $t: Type;
    constructor();
    private _tabArea;
    /**
     * Returns or sets the visual data for the area in the spreadsheet that contains the sheet tab items
     */
    tabArea: SpreadsheetTabItemAreaVisualData;
    private _cellAreas;
    /**
     * Returns or sets the visual data for the cell areas in the spreadsheet
     */
    cellAreas: SpreadsheetCellAreaVisualDataList;
    private _rowHeaderAreas;
    /**
     * Returns or sets the visual data for the row header areas in the spreadsheet
     */
    rowHeaderAreas: SpreadsheetHeaderAreaVisualDataList;
    private _columnHeaderAreas;
    /**
     * Returns or sets the visual data for the column header areas in the spreadsheet
     */
    columnHeaderAreas: SpreadsheetHeaderAreaVisualDataList;
    /**
     * Returns a string representation of the visual data
     */
    serialize(): string;
    /**
     * @hidden
     */
    static _g(a: any): string;
    /**
     * @hidden
     */
    static _f(a: IEnumerable): string;
    /**
     * @hidden
     */
    static _h(a: string[], b: any[]): string;
}
/**
 * Represents the visual data for a row or column header area within the spreadsheet
 */
export declare class SpreadsheetHeaderAreaVisualData extends SpreadsheetVisualDataBase {
    static $t: Type;
    constructor();
    private _relativeBounds;
    /**
     * The position of the area within the containing visual.
     */
    relativeBounds: RectData;
    private _items;
    /**
     * The visual information about the items in the header
     */
    items: SpreadsheetRowColumnVisualDataList;
    private _shapes;
    /**
     * The visual shape data of the header area.
     */
    shapes: PrimitiveVisualDataList;
    /**
     * Returns a string representation of the visual data
     */
    serialize(): string;
}
/**
 * Represents the visual data for a list of row or column header areas within the spreadsheet
 */
export declare class SpreadsheetHeaderAreaVisualDataList extends List$1<SpreadsheetHeaderAreaVisualData> {
    static $t: Type;
    constructor();
}
/**
 * Represents the visual data for a cell area within the spreadsheet
 */
export declare class SpreadsheetCellAreaVisualData extends SpreadsheetVisualDataBase {
    static $t: Type;
    constructor();
    private _relativeBounds;
    /**
     * The position of the area within the containing visual.
     */
    relativeBounds: RectData;
    private _columns;
    /**
     * The visual information about the columns for the cells
     */
    columns: SpreadsheetRowColumnVisualDataList;
    private _rows;
    /**
     * The visual information about the rows for the cells
     */
    rows: SpreadsheetRowColumnVisualDataList;
    private _shapes;
    /**
     * The visual shape data of the header area.
     */
    shapes: PrimitiveVisualDataList;
    /**
     * Returns a string representation of the visual data
     */
    serialize(): string;
}
/**
 * Represents the visual data for a list of cell areas within the spreadsheet
 */
export declare class SpreadsheetCellAreaVisualDataList extends List$1<SpreadsheetCellAreaVisualData> {
    static $t: Type;
    constructor();
}
/**
 * Represents the visual data for a row or column within the spreadsheet
 */
export declare class SpreadsheetRowColumnVisualData extends SpreadsheetVisualDataBase {
    static $t: Type;
    private _index;
    /**
     * The index of the associated row or column.
     */
    index: number;
    private _offset;
    /**
     * The start offset of the row or column within the containing visual.
     */
    offset: number;
    private _extent;
    /**
     * The extent of the row or column within the containing visual.
     */
    extent: number;
    /**
     * Returns a string representation of the visual data
     */
    serialize(): string;
}
/**
 * Represents the visual data for a list of row or column headers within the spreadsheet
 */
export declare class SpreadsheetRowColumnVisualDataList extends List$1<SpreadsheetRowColumnVisualData> {
    static $t: Type;
    constructor();
}
/**
 * Represents the visual data for the area containing the sheet tabs
 */
export declare class SpreadsheetTabItemAreaVisualData extends SpreadsheetVisualDataBase {
    static $t: Type;
    constructor();
    private _relativeBounds;
    /**
     * The position of the area within the containing visual.
     */
    relativeBounds: RectData;
    private _tabs;
    /**
     * The visual information about the sheet tab items
     */
    tabs: SpreadsheetTabVisualDataList;
    /**
     * Returns a string representation of the visual data
     */
    serialize(): string;
}
/**
 * Represents the visual data for a sheet tab within the spreadsheet
 */
export declare class SpreadsheetTabVisualData extends SpreadsheetVisualDataBase {
    static $t: Type;
    private _sheetIndex;
    /**
     * The index of the associated Sheet.
     */
    sheetIndex: number;
    private _color;
    /**
     * The color associated with the sheet.
     */
    color: ColorData;
    private _isActive;
    /**
     * If the sheet is active
     */
    isActive: boolean;
    private _isEditing;
    /**
     * If the sheet is in edit mode
     */
    isEditing: boolean;
    private _isProtected;
    /**
     * If the sheet is protected
     */
    isProtected: boolean;
    private _isSelected;
    /**
     * If the sheet is selected
     */
    isSelected: boolean;
    private _relativeBounds;
    /**
     * The position of the tab relative to the tab area.
     */
    relativeBounds: RectData;
    /**
     * Returns a string representation of the visual data
     */
    serialize(): string;
}
/**
 * Represents the visual data for a list of sheet tabs within the spreadsheet
 */
export declare class SpreadsheetTabVisualDataList extends List$1<SpreadsheetTabVisualData> {
    static $t: Type;
    constructor();
}
